<?php
/**
 * Double Category Post Widget Style
 *
 * @package MasterStroke
 */
if (!function_exists('MasterStroke_Mixed_Articles_Blocks')) :
    /**
     * Load widgets.
     *
     * @since 1.0.0
     */
    function MasterStroke_Mixed_Articles_Blocks()
    {
        register_widget('MasterStroke_Mixed_Articles_Blocks');
    }
endif;
add_action('widgets_init', 'MasterStroke_Mixed_Articles_Blocks');
// Article Widget Carousel Layout
if (!class_exists('MasterStroke_Mixed_Articles_Blocks')) :
    /**
     * Article Widget Carousel Layout
     *
     * @since 1.0.0
     */
    class MasterStroke_Mixed_Articles_Blocks extends MasterStroke_Widget_Base
    {
        /**
         * Sets up a new widget instance.
         *
         * @since 1.0.0
         */
        function __construct()
        {
            $opts = array(
                'classname' => 'MasterStroke_Mixed_Articles_Blocks',
                'description' => esc_html__('Displays post form selected category in two Colum with list and grid', 'masterstroke'),
                'customize_selective_refresh' => true,
            );
            $fields = array(
                'title' => array(
                    'label' => esc_html__('Section Title for List:', 'masterstroke'),
                    'type' => 'text',
                    'class' => 'widefat',
                ),
                'post_category_list' => array(
                    'label' => esc_html__('Select Category for List:', 'masterstroke'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('All Categories', 'masterstroke'),
                ),
                'post_category_grid' => array(
                    'label' => esc_html__('Select Category for Grid:', 'masterstroke'),
                    'type' => 'dropdown-taxonomies',
                    'show_option_all' => esc_html__('All Categories', 'masterstroke'),
                ),
                'enable_meta' => array(
                    'label' => esc_html__('Enable Categories:', 'masterstroke'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
                'enable_meta_1' => array(
                    'label' => esc_html__('Enable Date & Author:', 'masterstroke'),
                    'type' => 'checkbox',
                    'default' => true,
                ),
            );
            parent::__construct('masterstroke-double-cat-post-style', esc_html__('MasterStroke: Mixed Articles Blocks', 'masterstroke'), $opts, array(), $fields);
        }

        /**
         * Outputs the content for the current widget instance.
         *
         * @param array $args Display arguments.
         * @param array $instance Settings for the current widget instance.
         * @since 1.0.0
         *
         */
        function widget($args, $instance)
        {
            $params = $this->get_params($instance);
            echo $args['before_widget'];
            $qargs_1 = array(
                'post_type' => 'post',
                'posts_per_page' => 5,
                'post__not_in' => get_option("sticky_posts"),
            );
            $cat_link = "";

            if (is_rtl()) {
                $rtl = 'true';
            } else {
                $rtl = 'false';
            }

            if (absint($params['post_category_list']) > 0) {
                $qargs_1['cat'] = absint($params['post_category_list']);
                $cat_link = get_category_link($params['post_category_list']);
            }
            $qargs_2 = array(
                'post_type' => 'post',
                'posts_per_page' => 3,
                'post__not_in' => get_option("sticky_posts"),
            );
            $cat_link = "";

            if (is_rtl()) {
                $rtl = 'true';
            } else {
                $rtl = 'false';
            }

            if (absint($params['post_category_grid']) > 0) {
                $qargs_2['cat'] = absint($params['post_category_grid']);
                $cat_link = get_category_link($params['post_category_grid']);
            }
            ?>
            <div class="widget-layout widget-layout-contentrich">
            <?php if (!empty($params['title'])) { ?>
            <header class="theme-widget-header">
                <div class="theme-widget-title">
                    <h2 class="widget-title">
                        <?php echo $params['title'] ?>
                    </h2>
                </div>
            </header>
        <?php } ?>

            <div class="theme-widget-content">
            <?php $style_1_posts_query = new WP_Query($qargs_1);
            if ($style_1_posts_query->have_posts()) : ?>
                <div class="theme-widget-panel widget-panel-1">
                    <?php
                    while ($style_1_posts_query->have_posts()) :
                        $style_1_posts_query->the_post(); ?>

                        <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article news-article-instant'); ?>>
                            <div class="article-content-icon">
                                <?php masterstroke_theme_svg('special-arrow-right'); ?>
                            </div>
                            <div class="article-content">
                                <div class="entry-meta">
                                    <?php masterstroke_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                                </div>
                                <h3 class="entry-title entry-title-small">
                                    <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark"
                                       title="<?php the_title_attribute(); ?>">
                                        <?php the_title(); ?>
                                    </a>
                                </h3>
                                <div class="entry-meta">
                                    <?php masterstroke_posted_by(); ?>
                                    <?php masterstroke_post_view_count(); ?>
                                </div>
                            </div>

                        </article>

                        <?php
                        wp_reset_postdata();
                    endwhile; ?>
                </div>
            <?php endif; ?>
            <?php $style_2_posts_query = new WP_Query($qargs_2);
            if ($style_2_posts_query->have_posts()) : ?>
                <?php
                $count = 1; ?>
                <div class="theme-widget-panel widget-panel-2">

                <?php while ($style_2_posts_query->have_posts()) :
                    $style_2_posts_query->the_post();
                    $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                    $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                    <?php if ($count == 1) { ?>

                    <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article news-article-panel'); ?>>
                        <div class="data-bg data-bg-medium data-bg-overlay"
                             data-background="<?php echo esc_url($featured_image); ?>">
                            <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>
                        </div>
                        <div class="article-content mt-20">
                            <div class="entry-meta">
                                <?php masterstroke_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                            </div>
                            <h3 class="entry-title entry-title-big">
                                <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark"
                                   title="<?php the_title_attribute(); ?>">
                                    <?php the_title(); ?>
                                </a>
                            </h3>
                            <div class="entry-meta">
                                <?php masterstroke_posted_by(); ?>
                                <?php masterstroke_post_view_count(); ?>
                            </div>
                        </div>

                    </article>

                    </div>
                    <div class="theme-widget-panel widget-panel-3">
                    <?php $count++;
                } else { ?>

                    <article id="theme-post-<?php the_ID(); ?>" <?php post_class('news-article news-article-panel'); ?>>
                        <div class="data-bg data-bg-small data-bg-overlay"
                             data-background="<?php echo esc_url($featured_image); ?>">
                            <a class="img-link" href="<?php the_permalink(); ?>" tabindex="0"></a>
                        </div>
                        <div class="article-content mt-15">
                            <div class="entry-meta">
                                <?php masterstroke_entry_footer($cats = true, $tags = false, $edits = false, $text = false, $icon = false); ?>
                            </div>
                            <h3 class="entry-title entry-title-medium">
                                <a href="<?php the_permalink(); ?>" tabindex="0" rel="bookmark"
                                   title="<?php the_title_attribute(); ?>">
                                    <?php the_title(); ?>
                                </a>
                            </h3>
                            <div class="entry-meta">
                                <?php masterstroke_posted_by(); ?>
                                <?php masterstroke_post_view_count(); ?>
                            </div>
                        </div>

                    </article>

                <?php } ?>
                    <?php
                    wp_reset_postdata();
                endwhile; ?>
                </div>

                </div>
                </div>

            <?php endif;
            echo $args['after_widget'];
        }
    }
endif;